@@ -1,8 +1,8 @@
-#!/usr/bin/perl -I.. -w
+#!/usr/bin/perl -w -I/tmp
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
-# $Id: test.pl,v 1.8 2000/09/12 12:29:47 jrennie Exp $
+# $Id: test.pl,v 1.9 2001/11/22 17:48:02 jrennie Exp $
 
 ######################### We start with some black magic to print on failure.
 
@@ -21,8 +21,12 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
-print STDERR "Loading index files.  This may take a while...\n";
-my $wn = WordNet::QueryData->new ("/usr/local.foo/dict", 0);
+my $wnDir = $ENV{"WNHOME"}."/dict";
+
+print "Loading index files.  This may take a while...\n";
+my $wn = WordNet::QueryData->new ($wnDir, 0);
+
+print "Tests 2-15 work for both WordNet 1.6 and 1.7\n";
 
 (([$wn->forms ("blauboks#1")]->[1]) eq "blaubok"
     and ([$wn->forms ("boogied#2")]->[1]) eq "boogie"
@@ -52,24 +56,25 @@ scalar $wn->query ("cat#n#1", "hypo") == 2
     ? print "ok 10\n" : print "not ok 10\n";
 scalar $wn->query ("cat#noun#7", "syns") == 5
     ? print "ok 11\n" : print "not ok 11\n";
-scalar $wn->query ("run#verb") == 42
+scalar $wn->valid_forms ("lay down#v") == 2
     ? print "ok 12\n" : print "not ok 12\n";
-
-(([$wn->valid_forms ("lay up#1")]->[0]) eq "lay up"
-    and ([$wn->valid_forms ("lay down#2")]->[0]) eq "lay down"
-    and ([$wn->valid_forms ("ghostliest#3")]->[0]) eq "ghostly"
-    and ([$wn->valid_forms ("farther#4")]->[1]) eq "far")
+scalar $wn->valid_forms ("checked#v") == 1
     ? print "ok 13\n" : print "not ok 13\n";
 
-scalar $wn->valid_forms ("lay down#v") == 2
-    ? print "ok 14\n" : print "not ok 14\n";
-scalar $wn->valid_forms ("checked#v") == 1
-    ? print "ok 15\n" : print "not ok 15\n";
-
 ($wn->query ("cat#n#1", "glos") eq "feline mammal usually having thick soft fur and being unable to roar; domestic cats; wildcats  ") ? print
-"ok 16\n" : print "not ok 16\n";
+"ok 14\n" : print "not ok 14\n";
 
 scalar $wn->query ("child#n#1", "syns") == 12
+    ? print "ok 15\n" : print "not ok 15\n";
+
+(([$wn->valid_forms ("lay down#2")]->[0]) eq "lay down"
+    and ([$wn->valid_forms ("ghostliest#3")]->[0]) eq "ghostly"
+    and ([$wn->valid_forms ("farther#4")]->[1]) eq "far")
+    ? print "ok 16\n" : print "not ok 16\n";
+
+print "Tests 17-20 only work for WordNet 1.6\n";
+
+scalar $wn->query ("run#verb") == 42
     ? print "ok 17\n" : print "not ok 17\n";
 
 $wn->offset ("child#n#1") == 7153837
@@ -80,3 +85,18 @@ scalar $wn->query ("car#n#1", "mero") == 29
 
 scalar $wn->list_all_words("noun") == 94474
     ? print "ok 20\n" : print "not ok 20\n";
+
+print "Tests 21-24 only work for WordNet 1.7\n";
+
+scalar $wn->query ("run#verb") == 41
+    ? print "ok 21\n" : print "not ok 21\n";
+
+scalar $wn->list_all_words("noun") == 107930
+    ? print "ok 22\n" : print "not ok 22\n";
+
+$wn->offset ("child#n#1") == 7964378
+    ? print "ok 23\n" : print "not ok 23\n";
+
+scalar $wn->query ("car#n#1", "mero") == 28
+    ? print "ok 24\n" : print "not ok 24\n";
+
